AITranscriberSettings class

Constructors

AITranscriberSettings({SourceLanguage sourceLanguage = SourceLanguage.chineseEnglish, TranslationLanguage? translationLanguage = TranslationLanguage.english, bool showBilingual = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBilingual bool
final
sourceLanguage SourceLanguage
final
translationLanguage TranslationLanguage?
final

Methods

copyWith({SourceLanguage? sourceLanguage, TranslationLanguage? translationLanguage, bool clearTranslationLanguage = false, bool? showBilingual}) AITranscriberSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toTranscriberConfig() TranscriberConfig

Operators

operator ==(Object other) bool
The equality operator.
inherited