DialogOverlayManager class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
dismiss(
String dialogId) → void -
dismissAll(
) → void -
exists(
String dialogId) → bool -
setVisable(
String dialogId, bool visiable) → void -
show(
{required BuildContext context, required String dialogId, required Widget dialog, bool barrierDismissible = true, Color barrierColor = Colors.black54, bool rootOverlay = true, bool enableHide = false}) → void