RoundedCornerShape class

Inheritance

Constructors

RoundedCornerShape({required List<double> radii, BorderSide side = BorderSide.none})
const

Properties

dimensions → EdgeInsetsGeometry
The widths of the sides of this border represented as an EdgeInsets.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
preferPaintInterior → bool
Reports whether paintInterior is implemented.
no setterinherited
radii → List<double>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
side → BorderSide
final

Methods

add(ShapeBorder other, {bool reversed = false}) → ShapeBorder?
Attempts to create a new object that represents the amalgamation of this border and the other border.
inherited
copyWith({List<double>? radii, BorderSide? side}) → RoundedCornerShape
getInnerPath(Rect rect, {TextDirection? textDirection}) → Path
Create a Path that describes the inner edge of the border.
override
getOuterPath(Rect rect, {TextDirection? textDirection}) → Path
Create a Path that describes the outer edge of the border.
override
lerpFrom(ShapeBorder? a, double t) → ShapeBorder?
Linearly interpolates from another ShapeBorder (possibly of another class) to this.
inherited
lerpTo(ShapeBorder? b, double t) → ShapeBorder?
Linearly interpolates from this to another ShapeBorder (possibly of another class).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Rect rect, {TextDirection? textDirection}) → void
Paints the border within the given Rect on the given Canvas.
override
paintInterior(Canvas canvas, Rect rect, Paint paint, {TextDirection? textDirection}) → void
Paint a canvas with the appropriate shape.
inherited
scale(double t) → ShapeBorder
Creates a copy of this border, scaled by the factor t.
override
toString() → String
A string representation of this object.
inherited

Operators

operator +(ShapeBorder other) → ShapeBorder
Creates a new border consisting of the two borders on either side of the operator.
inherited
operator ==(Object other) → bool
The equality operator.
inherited