callCurrentPackageDoesNotSupportFeature property

String get callCurrentPackageDoesNotSupportFeature

No description provided for @callCurrentPackageDoesNotSupportFeature.

In en, this message translates to: 'Your current package type does not support this feature. To unlock more capabilities, we recommend upgrading your package in the Tencent Cloud Real-Time Audio and Video console'

Implementation

String get callCurrentPackageDoesNotSupportFeature;