callFeatureRequiresAudioVideoCallingPackage property

String get callFeatureRequiresAudioVideoCallingPackage

No description provided for @callFeatureRequiresAudioVideoCallingPackage.

In en, this message translates to: 'This feature requires the audio and video calling capability package. To avoid affecting your usage, we recommend going to the Tencent Cloud Real-Time Audio and Video console to activate the free trial or purchase a formal package'

Implementation

String get callFeatureRequiresAudioVideoCallingPackage;