callMicrophoneOrCameraPermissionNotEnabled property
No description provided for @callMicrophoneOrCameraPermissionNotEnabled.
In en, this message translates to: 'Microphone permission is not enabled, unable to start audio call. Go to 'Settings > TUICallKit' to enable microphone permission; Camera permission is not enabled, unable to start video call. Go to 'Settings > TUICallKit' to enable camera permission'
Implementation
@override
String get callMicrophoneOrCameraPermissionNotEnabled =>
'لم يتم تمكين إذن الميكروفون، لا يمكن بدء مكالمة صوتية. انتقل إلى \'الإعدادات > TUICallKit\' لتمكين إذن الميكروفون؛ لم يتم تمكين إذن الكاميرا، لا يمكن بدء مكالمة فيديو. انتقل إلى \'الإعدادات > TUICallKit\' لتمكين إذن الكاميرا';