callNeedToAccessMicrophoneAndCameraPermissions property
No description provided for @callNeedToAccessMicrophoneAndCameraPermissions.
In en, this message translates to: 'You need to access your microphone and camera permissions, which can be used for voice calls, multi-person voice calls, video calls, multi-person video calls, etc.'
Implementation
@override
String get callNeedToAccessMicrophoneAndCameraPermissions =>
'تحتاج إلى الوصول إلى أذونات الميكروفون والكاميرا، والتي يمكن استخدامها للمكالمات الصوتية ومكالمات الفيديو وغيرها.';