callCurrentlyOnCallCannotInitiateAnother property

  1. @override
String get callCurrentlyOnCallCannotInitiateAnother
override

No description provided for @callCurrentlyOnCallCannotInitiateAnother.

In en, this message translates to: 'You are currently on a call, please end the current call before making another one'

Implementation

@override
String get callCurrentlyOnCallCannotInitiateAnother =>
    'You are currently on a call, please end the current call before making another one';