callFailedToInitiateCallCheckLoginStatus property

  1. @override
String get callFailedToInitiateCallCheckLoginStatus
override

No description provided for @callFailedToInitiateCallCheckLoginStatus.

In en, this message translates to: 'Failed to initiate call, please check your login status and try again'

Implementation

@override
String get callFailedToInitiateCallCheckLoginStatus =>
    'Failed to initiate call, please check your login status and try again';