callMicrophoneOrCameraPermissionNotEnabled property

  1. @override
String get callMicrophoneOrCameraPermissionNotEnabled
override

No description provided for @callMicrophoneOrCameraPermissionNotEnabled.

In en, this message translates to: 'Microphone permission is not enabled, unable to start audio call. Go to 'Settings > TUICallKit' to enable microphone permission; Camera permission is not enabled, unable to start video call. Go to 'Settings > TUICallKit' to enable camera permission'

Implementation

@override
String get callMicrophoneOrCameraPermissionNotEnabled =>
    'Microphone permission is not enabled, unable to start audio call. Go to \'Settings > TUICallKit\' to enable microphone permission; Camera permission is not enabled, unable to start video call. Go to \'Settings > TUICallKit\' to enable camera permission';