callFeatureRequiresAudioVideoCallingPackage property
No description provided for @callFeatureRequiresAudioVideoCallingPackage.
In en, this message translates to: 'This feature requires the audio and video calling capability package. To avoid affecting your usage, we recommend going to the Tencent Cloud Real-Time Audio and Video console to activate the free trial or purchase a formal package'
Implementation
@override
String get callFeatureRequiresAudioVideoCallingPackage =>
'この機能には音声/ビデオ通話パッケージが必要です。使用に影響を与えないように、Tencent Cloud Real-Time Audio and Video コンソールで無料トライアルをアクティブにするか、正式なパッケージを購入することをお勧めします';