callMicrophoneOrCameraPermissionNotEnabled property
No description provided for @callMicrophoneOrCameraPermissionNotEnabled.
In en, this message translates to: 'Microphone permission is not enabled, unable to start audio call. Go to 'Settings > TUICallKit' to enable microphone permission; Camera permission is not enabled, unable to start video call. Go to 'Settings > TUICallKit' to enable camera permission'
Implementation
@override
String get callMicrophoneOrCameraPermissionNotEnabled =>
'マイク権限が有効になっていないため、音声通話を開始できません。\'設定 > TUICallKit\' でマイク権限を有効にしてください。カメラ権限が有効になっていないため、ビデオ通話を開始できません。\'設定 > TUICallKit\' でカメラ権限を有効にしてください';