callNeedToAccessMicrophonePermission property
No description provided for @callNeedToAccessMicrophonePermission.
In en, this message translates to: 'You need to access your microphone permission, which can be used for voice calls, multi-person voice calls, video calls, multi-person video calls and other functions after being turned on.'
Implementation
@override
String get callNeedToAccessMicrophonePermission =>
'マイクへのアクセス許可が必要で、音声/ビデオ通話、グループ音声/ビデオ通話などの機能に使用できます。マイクをオンにした場合のみ、録画した動画に音声が保存されます。';