callCurrentPackageDoesNotSupportFeature property
No description provided for @callCurrentPackageDoesNotSupportFeature.
In en, this message translates to: 'Your current package type does not support this feature. To unlock more capabilities, we recommend upgrading your package in the Tencent Cloud Real-Time Audio and Video console'
Implementation
@override
String get callCurrentPackageDoesNotSupportFeature =>
'현재 패키지 유형은 이 기능을 지원하지 않습니다. 더 많은 기능을 잠금 해제하려면 Tencent Cloud 실시간 오디오/비디오 콘솔에서 패키지를 업그레이드하는 것을 권장합니다';