callFeatureRequiresAudioVideoCallingPackage property
No description provided for @callFeatureRequiresAudioVideoCallingPackage.
In en, this message translates to: 'This feature requires the audio and video calling capability package. To avoid affecting your usage, we recommend going to the Tencent Cloud Real-Time Audio and Video console to activate the free trial or purchase a formal package'
Implementation
@override
String get callFeatureRequiresAudioVideoCallingPackage =>
'이 기능은 오디오/비디오 통화 기능 패키지가 필요합니다. 사용에 영향을 주지 않도록 Tencent Cloud 실시간 오디오/비디오 콘솔에서 무료 체험을 활성화하거나 정식 패키지를 구매하는 것을 권장합니다';