callMicrophoneOrCameraPermissionNotEnabled property
No description provided for @callMicrophoneOrCameraPermissionNotEnabled.
In en, this message translates to: 'Microphone permission is not enabled, unable to start audio call. Go to 'Settings > TUICallKit' to enable microphone permission; Camera permission is not enabled, unable to start video call. Go to 'Settings > TUICallKit' to enable camera permission'
Implementation
@override
String get callMicrophoneOrCameraPermissionNotEnabled =>
'마이크 권한이 활성화되지 않아 음성 통화를 시작할 수 없습니다. \'설정 > TUICallKit\'에서 마이크 권한을 활성화하세요. 카메라 권한이 활성화되지 않아 영상 통화를 시작할 수 없습니다. \'설정 > TUICallKit\'에서 카메라 권한을 활성화하세요';