base_component/localizations/atomic_localizations_zh library
Classes
- AtomicLocalizationsZh
-
The translations for Chinese (
zh). - AtomicLocalizationsZhHans
-
The translations for Chinese, using the Han script (
zh_Hans). - AtomicLocalizationsZhHant
-
The translations for Chinese, using the Han script (
zh_Hant).