callCurrentPackageDoesNotSupportFeature property

  1. @override
String get callCurrentPackageDoesNotSupportFeature
override

No description provided for @callCurrentPackageDoesNotSupportFeature.

In en, this message translates to: 'Your current package type does not support this feature. To unlock more capabilities, we recommend upgrading your package in the Tencent Cloud Real-Time Audio and Video console'

Implementation

@override
String get callCurrentPackageDoesNotSupportFeature =>
    '您当前的套餐类型暂不支持此功能,为解锁更多能力,建议您前往腾讯云·实时音视频控制台升级套餐';