callFeatureRequiresAudioVideoCallingPackage property

  1. @override
String get callFeatureRequiresAudioVideoCallingPackage
override

No description provided for @callFeatureRequiresAudioVideoCallingPackage.

In en, this message translates to: 'This feature requires the audio and video calling capability package. To avoid affecting your usage, we recommend going to the Tencent Cloud Real-Time Audio and Video console to activate the free trial or purchase a formal package'

Implementation

@override
String get callFeatureRequiresAudioVideoCallingPackage =>
    '此功能需要音视频通话能力套餐支持,为不影响您的使用,建议您前往腾讯云·实时音视频控制台,开通免费体验或选购正式套餐';