callCurrentPackageDoesNotSupportFeature property
No description provided for @callCurrentPackageDoesNotSupportFeature.
In en, this message translates to: 'Your current package type does not support this feature. To unlock more capabilities, we recommend upgrading your package in the Tencent Cloud Real-Time Audio and Video console'
Implementation
@override
String get callCurrentPackageDoesNotSupportFeature =>
'您當前的套餐類型暫不支持此功能,為解鎖更多能力,建議您前往騰訊雲·實時音視頻控制台升級套餐';