ThemeState class

Inheritance

Constructors

ThemeState()

Properties

colors → SemanticColorScheme
no setter
currentPrimaryColor → String?
no setter
currentTheme → ThemeConfig
no setter
currentType → ThemeType
no setter
fonts → SemanticFontScheme
no setter
hasCustomPrimaryColor → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isDarkMode → bool
no setter
radius → SemanticRadiusScheme
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → SemanticSpacingScheme
no setter
themeKey → String
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearPrimaryColor() → void
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
saveTheme() → Future<void>
setPrimaryColor(String hexColor) → void
setThemeMode(ThemeType type) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited