AppBuilder class

Properties

avatarConfig ↔ AvatarConfig
getter/setter pair
conversationListConfig ↔ ConversationListConfig
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messageInputConfig ↔ MessageInputConfig
getter/setter pair
messageListConfig ↔ MessageListConfig
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchConfig ↔ SearchConfig
getter/setter pair
themeConfig ↔ AtomicThemeConfig
getter/setter pair
translateConfig ↔ TranslateConfig
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getInstance() → AppBuilder
init({required String path}) → Future<void>