ImagePicker class

Constructors

ImagePicker()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

pickImages({ImagePickerConfig? config, AlbumPickerTheme? theme, dynamic onPickConfirm(List<AlbumMedia> pickedAlbumMedias, String? textMessage)?, dynamic onMediaProcessing(AlbumMedia albumMedia, double progress, bool error)?, dynamic onMediaProcessed()?, dynamic onCancel()?}) Future<void>