ImageUploader class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
pick(
{required BuildContext context, ImageUploaderConfig? config, String? cosUploadURL, required dynamic onPickCompleted(String? localPath), dynamic onCosUploadCompleted(int statusCode)?}) → Future< void> - Pick an image with optional cropping and COS upload.