ImageCosUploadManager class

Constructors

ImageCosUploadManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
uploadFile(String localPath, String cosUploadURL) Future<int>
Upload file to COS Returns HTTP status code, or -1 on failure

Operators

operator ==(Object other) bool
The equality operator.
inherited