MentionInfo class

MentionInfo represents a mention (@) in the message input.

Constructors

MentionInfo({required String userID, required String displayName, required int startIndex})

Properties

displayName String
final
endIndex int
no setter
hashCode int
The hash code for this object.
no setterinherited
isAtAll bool
no setter
length int
no setter
mentionText String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startIndex int
getter/setter pair
userID String
final

Methods

copyWith({String? userID, String? displayName, int? startIndex}) MentionInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

atAllUserID → const String
Special userID for @All