VoiceToTextFailure class

Conversion failed (upload error, convert error, empty result, or timeout).

Inheritance

Constructors

VoiceToTextFailure({required int code, String? message, bool isTimeout = false})
const

Properties

code int
final
hashCode int
The hash code for this object.
no setterinherited
isTimeout bool
final
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited