VoiceToTextManager class

Stateless manager: build once, call convert on demand.

Constructors

VoiceToTextManager({CallExperimentalApi? callExperimentalApi, Duration timeout = _defaultTimeout})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

convert(String filePath) Future<VoiceToTextResult>
Upload filePath then convert the uploaded URL to text.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited