VoiceToTextResult class abstract

Result of a voice-to-text conversion.

Sealed-style hierarchy (Dart 2 compatible): callers should switch on the runtime type via is VoiceToTextSuccess / is VoiceToTextFailure.

Implementers

Constructors

VoiceToTextResult()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited