message_list/message_list library

Classes

ChatMessageListConfig
CustomMessageWidget
DefaultMessageMenuCallbacks
MessageBubble
MessageCheckbox
Checkbox component for message multi-select mode
MessageCustomAction
MessageItem
MessageList
MessageListConfigProtocol
MessageReactionBar
Bar displaying message reactions below the message bubble
MultiSelectBottomBar
Bottom action bar for multi-select mode
MultiSelectCallbacks
Multi-select mode action callbacks
MultiSelectState
Multi-select mode state
ReactionDetailSheet
Bottom sheet showing reaction details with user list
ReactionEmojiPicker
Quick emoji picker for message reactions (6 emojis + expand button)
ReactionEmojiPickerSheet
Full emoji picker sheet for reactions
RecentEmojiManager
Manager for recent reaction emojis
SystemMessageWidget

Typedefs

OnCallMessageClick = void Function(String userID, bool isVideoCall)
Callback when call message is clicked in C2C conversation userID is the user ID of the other party isVideoCall is true for video call, false for voice call
OnMultiSelectModeChanged = void Function(bool isMultiSelectMode, int selectedCount)
Multi-select mode state callback
OnUserClick = void Function(String userID)
OnUserLongPress = void Function(String userID, String displayName)
Callback when user long presses on avatar (for @ mention feature) userID is the user ID of the message sender displayName is the display name of the message sender