AsrDisplayManager class

Manages the display state of ASR (Automatic Speech Recognition) text bubbles.

Core features:

  • Hidden set mode: Uses an in-memory Set
  • Shown by default: When asrText has value, the ASR text bubble is shown by default
  • Session-only: Hidden state only affects current session, lost when exiting message list
  • Re-entering chat: If asrText has value, it will be shown again
Inheritance

Constructors

AsrDisplayManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clear() → void
Clear all display states
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
hide(String messageID) → void
Hide the ASR text bubble for this session
isConverting(String messageID) bool
Check if the message is currently converting
isHidden(String messageID) bool
Check if the message's ASR text bubble is hidden (collapsed) in this session
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setConverting(String messageID, bool converting) → void
Mark message as converting
show(String messageID) → void
Show the ASR text bubble (remove from hidden set)
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited