CallCoreController class abstract

Controller for managing CallCoreView layout and state.

CallCoreController is used to control the layout template of CallCoreView. Create an instance using the factory method create().

Constructors

CallCoreController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Dispose the controller and release resources.
enableVideoZoomGesture(bool enable) → void
Enable or disable Video Zoom Gestures on larger video views (float main view and grid enlarged views). When enabled, users can pinch to zoom in/out on video views (center zoom only).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLayoutTemplate(CallLayoutTemplate template) → void
Set the layout template for the call view.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() CallCoreController
Factory method to create a CallCoreController instance.