MessageActionStore class abstract

Inheritance

Constructors

MessageActionStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
messageActionState MessageActionState
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addMessageReaction({required String reactionID}) Future<CompletionHandler>
convertVoiceToText({required String language}) Future<CompletionHandler>
deleteMessage() Future<CompletionHandler>
deleteMessageExtensions({List<String>? keys}) Future<CompletionHandler>
dispose() → void
Discards any resources used by the object.
inherited
fetchMessageReactionUsers({required String reactionID, required int count}) Future<CompletionHandler>
fetchMessageReadMembers({required int count}) Future<CompletionHandler>
fetchMessageUnreadMembers({required int count}) Future<CompletionHandler>
fetchMoreMessageMembers({required bool isRead}) Future<CompletionHandler>
fetchMoreMessageReactionUsers() Future<CompletionHandler>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pinMessage({required bool isPinned}) Future<CompletionHandler>
recallMessage() Future<CompletionHandler>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeMessageReaction({required String reactionID}) Future<CompletionHandler>
setMessageExtensions({required List<MessageExtension> extensions}) Future<CompletionHandler>
toString() String
A string representation of this object.
inherited
translateText({required List<String> sourceTextList, String? sourceLanguage, required String targetLanguage}) Future<CompletionHandler>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(MessageInfo message) MessageActionStore