SourceLanguage enum

Source language type for transcription recognition.

Defines the source language for speech recognition during real-time transcription. The transcriber will recognize speech in the specified source language and convert it to text.

Note: Choose the source language that matches the speaker's language for best recognition accuracy. Use chineseEnglish for mixed Chinese and English scenarios.

Source Language List

Language Value Description
chineseEnglish zh_en Chinese-English mixed
chinese zh Chinese
english en English
cantonese zh-yue Cantonese
vietnamese vi Vietnamese
japanese ja Japanese
korean ko Korean
indonesian id Indonesian
thai th Thai
portuguese pt Portuguese
turkish tr Turkish
arabic ar Arabic
spanish es Spanish
hindi hi Hindi
french fr French
malay ms Malay
filipino fil Filipino
german de German
italian it Italian
russian ru Russian
Inheritance
Available extensions

Values

chineseEnglish → const SourceLanguage

Chinese-English mixed recognition.

const SourceLanguage('zh_en')
chinese → const SourceLanguage

Chinese.

const SourceLanguage('zh')
english → const SourceLanguage

English.

const SourceLanguage('en')
cantonese → const SourceLanguage

Cantonese.

const SourceLanguage('zh-yue')
vietnamese → const SourceLanguage

Vietnamese.

const SourceLanguage('vi')
japanese → const SourceLanguage

Japanese.

const SourceLanguage('ja')
korean → const SourceLanguage

Korean.

const SourceLanguage('ko')
indonesian → const SourceLanguage

Indonesian.

const SourceLanguage('id')
thai → const SourceLanguage

Thai.

const SourceLanguage('th')
portuguese → const SourceLanguage

Portuguese.

const SourceLanguage('pt')
turkish → const SourceLanguage

Turkish.

const SourceLanguage('tr')
arabic → const SourceLanguage

Arabic.

const SourceLanguage('ar')
spanish → const SourceLanguage

Spanish.

const SourceLanguage('es')
hindi → const SourceLanguage

Hindi.

const SourceLanguage('hi')
french → const SourceLanguage

French.

const SourceLanguage('fr')
malay → const SourceLanguage

Malay.

const SourceLanguage('ms')
filipino → const SourceLanguage

Filipino.

const SourceLanguage('fil')
german → const SourceLanguage

German.

const SourceLanguage('de')
italian → const SourceLanguage

Italian.

const SourceLanguage('it')
russian → const SourceLanguage

Russian.

const SourceLanguage('ru')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SourceLanguage>
A constant List of the values in this enum, in order of their declaration.