TranslationLanguage enum

Target language type for translation.

Defines the target language for translation during real-time transcription. The transcriber will translate recognized text into the specified target languages.

Note: Multiple translation languages can be configured simultaneously. The translation results will be stored in the translationTexts map of TranscriberMessage.

Translation Language List

Language Value Description
chinese zh Chinese
english en English
vietnamese vi Vietnamese
japanese ja Japanese
korean ko Korean
indonesian id Indonesian
thai th Thai
portuguese pt Portuguese
arabic ar Arabic
spanish es Spanish
french fr French
malay ms Malay
german de German
italian it Italian
russian ru Russian
Inheritance
Available extensions

Values

chinese → const TranslationLanguage

Chinese.

const TranslationLanguage('zh')
english → const TranslationLanguage

English.

const TranslationLanguage('en')
vietnamese → const TranslationLanguage

Vietnamese.

const TranslationLanguage('vi')
japanese → const TranslationLanguage

Japanese.

const TranslationLanguage('ja')
korean → const TranslationLanguage

Korean.

const TranslationLanguage('ko')
indonesian → const TranslationLanguage

Indonesian.

const TranslationLanguage('id')
thai → const TranslationLanguage

Thai.

const TranslationLanguage('th')
portuguese → const TranslationLanguage

Portuguese.

const TranslationLanguage('pt')
arabic → const TranslationLanguage

Arabic.

const TranslationLanguage('ar')
spanish → const TranslationLanguage

Spanish.

const TranslationLanguage('es')
french → const TranslationLanguage

French.

const TranslationLanguage('fr')
malay → const TranslationLanguage

Malay.

const TranslationLanguage('ms')
german → const TranslationLanguage

German.

const TranslationLanguage('de')
italian → const TranslationLanguage

Italian.

const TranslationLanguage('it')
russian → const TranslationLanguage

Russian.

const TranslationLanguage('ru')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TranslationLanguage>
A constant List of the values in this enum, in order of their declaration.