ActionSheet class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
show(BuildContext context, {String? title, String? message, required List<ActionSheetItem> actions, String? cancelText, bool showCancel = true})
→ Future<void>
-
-
showModalBottomSheetBySystem<T>({required BuildContext context, required WidgetBuilder builder, Color? backgroundColor, String? barrierLabel, double? elevation, ShapeBorder? shape, Clip? clipBehavior, BoxConstraints? constraints, Color? barrierColor, bool isScrollControlled = false, double scrollControlDisabledMaxHeightRatio = _defaultScrollControlDisabledMaxHeightRatio, bool useRootNavigator = false, bool isDismissible = true, bool enableDrag = true, bool? showDragHandle, bool useSafeArea = false, RouteSettings? routeSettings, AnimationController? transitionAnimationController, Offset? anchorPoint, AnimationStyle? sheetAnimationStyle, VoidCallback? onDismiss})
→ ModalBottomSheetRoute
-
-
showWithRoute(BuildContext context, {String? title, String? message, required List<ActionSheetItem> actions, String? cancelText, bool showCancel = true})
→ ModalBottomSheetRoute
-