AlertDialogConfig class
Constructors
-
AlertDialogConfig({String title = '', String? content, Widget? iconWidget, bool autoDismiss = false, int countdownDuration = 0, ButtonConfig? confirmConfig, ButtonConfig? cancelConfig, List<
ButtonConfig> itemList = const [], @Deprecated('Use cancelConfig instead') String? cancelText, @Deprecated('Use confirmConfig instead') String? defaultText, @Deprecated('Use confirmConfig with type = TextColorPreset.red instead') bool isDestructive = false, @Deprecated('Use confirmConfig.onClick instead') VoidCallback? defaultCallback}) -
const
Properties
- autoDismiss → bool
-
final
- cancelConfig → ButtonConfig?
-
final
- cancelText → String?
-
final
- confirmConfig → ButtonConfig?
-
final
- content → String?
-
final
- countdownDuration → int
-
final
- defaultCallback → VoidCallback?
-
final
- defaultText → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconWidget → Widget?
-
final
- isDestructive → bool
-
final
-
itemList
→ List<
ButtonConfig> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited