callCurrentPackageDoesNotSupportFeature property
No description provided for @callCurrentPackageDoesNotSupportFeature.
In en, this message translates to: 'Your current package type does not support this feature. To unlock more capabilities, we recommend upgrading your package in the Tencent Cloud Real-Time Audio and Video console'
Implementation
@override
String get callCurrentPackageDoesNotSupportFeature =>
'نوع حزمتك الحالية لا يدعم هذه الميزة. لفتح المزيد من الإمكانيات، نوصي بترقية حزمتك في وحدة تحكم Tencent Cloud للصوت والفيديو في الوقت الفعلي';