callNeedToAccessMicrophonePermission property
No description provided for @callNeedToAccessMicrophonePermission.
In en, this message translates to: 'You need to access your microphone permission, which can be used for voice calls, multi-person voice calls, video calls, multi-person video calls and other functions after being turned on.'
Implementation
@override
String get callNeedToAccessMicrophonePermission =>
'تحتاج إلى الوصول إلى إذن الميكروفون الخاص بك، والذي يمكن استخدامه للمكالمات الصوتية ومكالمات الفيديو وغيرها من الوظائف بعد تشغيله.';