GroupPermissionManager class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
canPerformAction(
{required GroupType groupType, required GroupMemberRole memberRole, required GroupPermission action}) → bool -
getAvailablePermissions(
{required GroupType groupType, required GroupMemberRole memberRole}) → List< GroupPermission> -
getGroupTypeDescription(
GroupType groupType, BuildContext context) → String -
getMemberRoleDescription(
GroupMemberRole role, BuildContext context) → String -
hasPermission(
{required GroupType groupType, required GroupMemberRole memberRole, required GroupPermission permission}) → bool