RecentEmojiManager class
Manager for recent reaction emojis
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addRecentEmoji(
String emojiId) → Future< void> - Add emoji to recent list
-
getAllEmojis(
BuildContext context) → List< EmojiPickerModelItem> - Get all emojis for full picker
-
getEmojiByReactionID(
BuildContext context, String reactionID) → EmojiPickerModelItem? - Get emoji item by reactionID
-
getEmojiPath(
String reactionID) → String? - Get emoji path by reactionID (name)
-
getQuickEmojis(
BuildContext context) → Future< List< EmojiPickerModelItem> > - Get quick emojis for reaction picker (6 recent + fill with defaults)
-
getRecentEmojiIds(
) → Future< List< String> > - Get recent emoji IDs (reactionIDs)