MessageStatusMixin mixin
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildMessageStatusIndicator({required MessageInfo message, required bool isSelf, required SemanticColorScheme colorsTheme, bool isOverlay = false, VoidCallback? onResendTap, bool enableReadReceipt = false, bool isInMergedDetailView = false})
→ Widget
-
-
buildMessageTimeIndicator({required DateTime? dateTime, required SemanticColorScheme colorsTheme, bool isOverlay = false, bool isSelf = false})
→ Widget
-
-
buildOutsideBubbleStatusIndicator({required MessageInfo message, required SemanticColorScheme colorsTheme, VoidCallback? onResendTap})
→ Widget?
-
Build status indicator (sendFail, violation, or sending) - to be shown outside bubble
Returns null if no status to show
-
buildOutsideReadReceiptLabel({required MessageInfo message, required SemanticColorScheme colorsTheme, required AtomicLocalizations locale, required bool enableReadReceipt, bool isInMergedDetailView = false, VoidCallback? onTap})
→ Widget?
-
Build read receipt text label to be shown outside the bubble (on the left side).
-
buildStatusAndTimeWidgets({required MessageInfo message, required bool isSelf, required SemanticColorScheme colors, bool isOverlay = false, VoidCallback? onResendTap, bool isShowTimeInBubble = true, bool enableReadReceipt = false, bool isInMergedDetailView = false})
→ List<Widget>
-
-
hasErrorStatus(MessageInfo message)
→ bool
-
Check if message has error status (sendFail or violation)
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldShowStatusOutsideBubble(MessageInfo message)
→ bool
-
Check if message status should be shown outside bubble
-
toString()
→ String
-
A string representation of this object.
inherited